@@ -13,15 +13,23 @@ class BackslashTreeProcessor(Treeprocessor):
 		elements = etree.Element('div')
 
 		for element in root:
-			print('ELEMENT', element, element.tag, element.attrib, len(element), etree.tostring(element))
+			# print('ELEMENT', element, element.tag, element.attrib, len(element), etree.tostring(element))
 
 			# Paragraphs
 			if element.tag == 'p':
 				element.tag = 'li'
 				elements.append(element)
-				line = etree.Element('li')
-				line.tail = '\n'
-				elements.append(line)
+
+				# TODO
+				# for text in element.text.split('\n'):
+				# 	item = etree.Element('li')
+				# 	item.text = text
+				# 	item.tail = '\n'
+				# 	elements.append(item)
+
+				new_line = etree.Element('li')
+				new_line.tail = '\n'
+				elements.append(new_line)
 
 			# Headers
 			elif element.tag in ['h1', 'h2', 'h3', 'h4', 'h5', 'h6']:
@@ -81,15 +89,14 @@ class BackslashTreeProcessor(Treeprocessor):
 				for sub_element in element:
 
 					if sub_element.tag == 'code':
+						sub_element.text = sub_element.text.strip('\n')
 
 						for text in sub_element.text.split('\n'):
-
-							if text:
-								line = etree.Element('li')
-								line.attrib['class'] = 'codeblock'
-								line.text = text
-								line.tail = '\n'
-								elements.append(line)
+							line = etree.Element('li')
+							line.attrib['class'] = 'codeblock'
+							line.text = text
+							line.tail = '\n'
+							elements.append(line)
 
 						# sub_element.tag = 'li'
 						# sub_element.attrib['class'] = 'codeblock'
